@@ -172,6 +172,8 @@ pub mod wait_for_conditions;
 pub use self::wait_for_conditions::WaitForConditions;
 pub mod webhook_dto;
 pub use self::webhook_dto::WebhookDto;
+pub mod webhook_payload;
+pub use self::webhook_payload::WebhookPayload;
 pub mod webhook_projection;
 pub use self::webhook_projection::WebhookProjection;
 pub mod webhook_test_request;
